@@ -782,8 +782,6 @@ QPushButton* TextProcessor::getSendBt()
 /** Commit text to external app**/
 void TextProcessor::commit()
 {
-     parentWidget()->parentWidget()->hide();
-
     QDBusMessage msg = QDBusMessage::createMethodCall(
             "it.rsc.fastsms.plugin.connection", // --dest
             "/", // destination object path
@@ -796,9 +794,13 @@ void TextProcessor::commit()
     args.append(m_smsEdit->toPlainText());
     msg.setArguments(args);
     msg = QDBusConnection::sessionBus().call(msg);
-    qDebug() << msg;
+    //qDebug() << msg;
     bool ok = msg.type() != QDBusMessage::ErrorMessage;
 
+    parentWidget()->parentWidget()->hide();
+    qDebug() << "Sended:" << msg;
+    qDebug() << "Sending state:" << ok;
+
     //Reset fastwrite state
     if(!m_bQwertyEnable)
         m_smsEdit->disconnect();
